#===============================================================================
# Objetivos
#===============================================================================
# Reproduzir anlise apresentada em seminrio sobre EF em DBC
# com interao significativa.

# Complementar anlise de xemplo coletada na literatura e trazida pelos alunos.
#
# Experimento: ensaio de Cultivar de milho (A) e Manejo (B) (3^1 x 4^1) montado
# em DBC com 3 repeties.
#
#  apresentados duas alternativas de anlise:
# - Teste de Tukey
# - Teste de ScottKnott
#===============================================================================
# Elaborao: J.C.Faria - 2024-10-30 17:51:04
#===============================================================================

#.. Leitura dos dados
dad <- read.table('ef_dbc_sem.txt',
                  head=T,
                  stringsAsFactors=T)

str(dad)
summary(dad)

#.. Grfico dos efeitos
par(mfrow=c(2, 1))

with(dad,
  {
     #A/B
     interaction.plot(A, B, Y,
                      xlab='A',
                      ylab='Y',
                      col=1:4,
                      lwd=2,
                      ylim=c(min(Y), max(Y)),
                      type='b',
                      pch=19)

     #B/A
     interaction.plot(B, A, Y,
                      xlab='B',
                      ylab='Y',
                      col=1:3,
                      lwd=2,
                      ylim=c(min(Y), max(Y)),
                      type='b',
                      pch=19)
  }
)

#.. ANOVA
av_0 <- aov(Y ~ BLO + A + B + A*B,
            dad)
summary(av_0)

library(TukeyC)
cv(av_0)

#.. TCMM (Tukey)
#... B:A
tk1<- TukeyC(av_0,
            which='B:A',
            fl1=1)

# Verificar a DMS de B:A
tk1$out$MSD

#b1:A
summary(TukeyC(av_0,
               which='B:A',
               fl1=1))

#b2:A
summary(TukeyC(av_0,
               which='B:A',
               fl1=2))

#b3:A
summary(TukeyC(av_0,
               which='B:A',
               fl1=3))

#b4:A
summary(TukeyC(av_0,
               which='B:A',
               fl1=4))

#... A:B
tk_2 <- TukeyC(av_0,
              which='A:B',
              fl1=1)

# Verificar a DMS de A:B
tk_2$out$MSD

#a1:B
summary(TukeyC(av_0,
               which='A:B',
               fl1=1))

#a2:B
summary(TukeyC(av_0,
               which='A:B',
               fl1=2))

#a3:B
summary(TukeyC(av_0,
               which='A:B',
               fl1=3))

#.. TCMM (ScottKonott)
library(ScottKnott)

#b1:A
summary(SK(av_0,
           which='B:A',
           fl1=1))

#b2:A
summary(SK(av_0,
           which='B:A',
           fl1=2))

#b3:A
summary(SK(av_0,
           which='B:A',
           fl1=3))

#b4:A
summary(SK(av_0,
           which='B:A',
           fl1=4))

#... A:B
#a1:B
summary(SK(av_0,
           which='A:B',
           fl1=1))

#a2:B
summary(SK(av_0,
           which='A:B',
           fl1=2))

#a3:B
summary(SK(av_0,
           which='A:B',
           fl1=3))

#. Aninhamentos
# Pacote gmodels  necessrio para a funo: make.contrasts (abaixo)
library(gmodels)

#.. Contrastes
#... Matriz de contrastes: CULTIVAR (A)
                                   #a1  a2  a3
mca <- rbind('_a1 vs. (a2, a3)' = c( 2, -1, -1),
             '_a2 vs. a3'       = c( 0,  1, -1))


#... Matriz de contrastes: MANEJO (B)
                                       #b1  b2  b3  b4
mcb <- rbind('_b1 vs. (b2, b3, b4)' = c( 3, -1, -1, -1),
             '_b2 vs. (b3, b4)'     = c( 0,  2, -1, -1),
             '_b3 vs. b4'           = c( 0,  0,  1, -1))

#.. ANOVA com aninhamento de efeitos (A/B)
av_1 <- aov(Y ~ BLO + A + A/B,
            data=dad,
            contrasts=list('A'=make.contrasts(mca),
                           'B'=make.contrasts(mcb)))

## Comparar com av_0
summary(av_1)
summary(av_0)

## Fundamental para construir o constrastes abaixo
effects(av_1)[6:14]
coef(av_1)[6:14]

## Anlise preliminar no efeito de B dentro de cada nvel de A
summary(av_1,
        split=list('A:B'=list('a1/B'=c(1, 4, 7),
                              'a2/B'=c(2, 5, 8),
                              'a3/B'=c(3, 6, 9))))

#.. ANOVA com aninhamento de efeitos (B/A)
av_2 <- aov(Y ~ BLO + B + B/A,
            data=dad,
            contrasts=list('A'=make.contrasts(mca),
                           'B'=make.contrasts(mcb)))

## Comparar com av_0
summary(av_2)
summary(av_0)

## Fundamental para construir o constrastes abaixo
effects(av_2)[7:14]
coef(av_2)[7:14]

## Anlise preliminar no efeito de A dentro de cada nvel de B
summary(av_2,
        split=list('B:A'=list('b1/A'=c(1, 5),
                              'b2/A'=c(2, 6),
                              'b3/A'=c(3, 7),
                              'b4/A'=c(4, 8))))
